vott_json2df: Read VoTT JSON as data.frame

Description Usage Arguments Value Author(s)

Description

Tracks a VoTT JSON file and reads the tags and images to build a tidy data.frame

Usage

1
vott_json2df(json_path)

Arguments

json_path

Path to a VoTT json file

Value

a data.frame in long format with one row per bounding box

Author(s)

Abram Fleishman abram@conservationmetics.com


ConservationMetrics/drones documentation built on May 16, 2019, 4:05 a.m.