Description Usage Arguments Value Author(s)
Tracks a VoTT JSON file and reads the tags and images to build a tidy data.frame
1 | vott_json2df(json_path)
|
json_path |
Path to a VoTT json file |
a data.frame in long format with one row per bounding box
Abram Fleishman abram@conservationmetics.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.